@@ -133,7 +133,7 @@ class Network(object):
                 self._neuron_states = [neu.state.copy() for neu in self.neurons]
             else:
                 for neu, state in zip(self.neurons, self._neuron_states):
-                    neu.state = state.copy()
+                    neu.state[:] = state.copy()
 
         # synapses
         if repeat:
@@ -144,8 +144,9 @@ class Network(object):
                     self._synapse_states.append([state, syn.var2index_array.copy()])
             else:
                 for syn, (state, var_index) in zip(self.synapses, self._synapse_states):
-                    syn.state = tuple(st.copy() for st in state)
-                    syn.var2index_array = var_index.copy()
+                    for i, st in enumerate(state):
+                        syn.state[i][:] = st.copy()
+                    syn.var2index_array[:] = var_index.copy()
 
         # 3. format external inputs
         # --------------------------
@@ -158,7 +159,7 @@ class Network(object):
         if report:
             t0 = time.time()
         self._input(0, iterable_inputs, fixed_inputs, no_inputs)
-        self._step(ts[0], 0)
+        self._step(t=ts[0], run_idx=0)
 
         # record time
         if report:
@@ -171,7 +172,7 @@ class Network(object):
         for run_idx in range(1, run_length):
             t = ts[run_idx]
             self._input(run_idx, iterable_inputs, fixed_inputs, no_inputs)
-            self._step(t, run_idx)
+            self._step(t=t, run_idx=run_idx)
             if report and ((run_idx + 1) % report_gap == 0):
                 percent = (run_idx + 1) / run_length * 100
                 print('Run {:.1f}% using {:.3f} s.'.format(percent, time.time() - t0))
